@@ -3,7 +3,7 @@ use 5.018;
 use strict;
 use warnings;
 
-our $VERSION = '0.900';
+our $VERSION = '0.901';
 
 # ABSTRACT: Check and report status of various services needed by your app
 
@@ -24,12 +24,12 @@ sub new {
     my @checks;
     while ( my ( $key, $value ) = each %args ) {
         my $module;
-        if ($key =~ /^\+/) {
+        if ( $key =~ /^\+/ ) {
             $module = $key;
-            $module=~s/^\+//;
+            $module =~ s/^\+//;
         }
         else {
-            $module = 'Plack::App::ServiceStatus::'.$key;
+            $module = 'Plack::App::ServiceStatus::' . $key;
         }
         try {
             use_module($module);
@@ -42,7 +42,8 @@ sub new {
             );
         }
         catch {
-            $log->errorf("%s: cannot init %s: %s",__PACKAGE__, $module, $_);
+            $log->errorf( "%s: cannot init %s: %s", __PACKAGE__, $module,
+                $_ );
         };
     }
 
@@ -72,7 +73,7 @@ sub to_app {
 
         foreach my $check ( @{ $self->checks } ) {
             my ( $status, $message ) = try {
-                return $check->{class}->check($check->{args});
+                return $check->{class}->check( $check->{args} );
             }
             catch {
                 return 'nok', "$_";
@@ -108,7 +109,7 @@ Plack::App::ServiceStatus - Check and report status of various services needed b
 
 =head1 VERSION
 
-version 0.900
+version 0.901
 
 =head1 SYNOPSIS
 
@@ -118,7 +119,7 @@ version 0.900
 
   my $status_app = Plack::App::ServiceStatus->new(
       app           => 'your app',
-      DBIC          => $schema,
+      DBIC          => [ $schema, 'select 1' ],
       Elasticsearch => $es, # instance of Search::Elasticsearch
   );
 
@@ -133,7 +134,9 @@ version 0.900
       mount '/_status' => 'Plack::App::ServiceStatus' => (
           app                     => literal(__PACKAGE__),
           Redis                   => 'redis',
-          '+MyApp::ServiceStatus' => literal("foo"),
+          '+MyApp::ServiceStatus' => {
+                foo => literal("foo")
+          },
       );
       route '/some/endpoint' => 'some_controller.some_action';
       # ...
@@ -141,7 +144,7 @@ version 0.900
 
 
   # checking the status
-  curl http://localhost:3000/_status  | json_pp
+  curl http://localhost:3000/_status | json_pp
   {
      "app" : "Your app",
      "started_at" : 1465823638,
@@ -166,7 +169,7 @@ version 0.900
 
 C<Plack::App::ServiceStatus> implements a small
 L<Plack|https://metacpan.org/pod/Plack> application that you can use
-to get some status info on your application and the services needed by
+to get some status info about your application and the services needed by
 it.
 
 You can then use some monitoring software to periodically check if
@@ -190,8 +193,16 @@ Each check consists of a C<name> and a C<status>. The status can be
 C<ok> or C<nok>. A check might also contain a C<message>, which should
 be some description of the error or problem if the status is C<nok>.
 
+Each check has to implement a method named C<check> which will be
+called with name of the class and the arguments you specified when
+setting up C<Plack::App::ServiceStatus>. C<check> has to return either
+the string C<ok>, or the string C<nok> and a string containing an
+explanation.
+
 You can add your own checks by specifying a name starting with a C<+>
-sign, for example C<+My::App::SomeStatusCheck>.
+sign, for example C<+My::App::SomeStatusCheck>. Or send me a pull
+request to include your check in this distribution, or just release it
+yourself!
 
 =head2 Weirdness
 
@@ -206,8 +217,6 @@ that here an embedded app is the better fit.
 
 =over
 
-=item * proper documentation
-
 =item * tests
 
 =item * make sure the app is only initiated once when running in OX
