@@ -29,7 +29,19 @@ Plack::App::ServiceStatus::Elasticsearch - Check Elasticsearch connection
 
 =head1 VERSION
 
-version 0.900
+version 0.901
+
+=head1 SYNOPSIS
+
+  my $es         = Search::Elasticsearch->new;
+  my $status_app = Plack::App::ServiceStatus->new(
+      app           => 'your app',
+      Elasticsearch => $es,
+  );
+
+=head1 CHECK
+
+Calls C<ping> on the C<$elasticsearch> object.
 
 =head1 AUTHOR
 
