@@ -29,7 +29,19 @@ Plack::App::ServiceStatus::Redis - Check Redis connection
 
 =head1 VERSION
 
-version 0.900
+version 0.901
+
+=head1 SYNOPSIS
+
+  my $redis      = Redis->new;
+  my $status_app = Plack::App::ServiceStatus->new(
+      app   => 'your app',
+      Redis => $redis,
+  );
+
+=head1 CHECK
+
+Calls C<ping> on the C<$redis> object.
 
 =head1 AUTHOR
 
